;;; -*- no-byte-compile: t -*-
(define-package "modus-themes" "1.0.2" "set of accessible themes conforming with WCAG AAA accessibility standard" 'nil :url "https://gitlab.com/protesilaos/modus-themes")
